@@ -888,6 +888,22 @@ class Akismet_Admin {
 		) );
 	}
 
+	public static function get_usage_limit_alert_data() {
+		return array(
+			'type'         => 'usage-limit',
+			'code'         => (int) get_option( 'akismet_alert_code' ),
+			'msg'          => get_option( 'akismet_alert_msg' ),
+			'api_calls'    => get_option( 'akismet_alert_api_calls' ),
+			'usage_limit'  => get_option( 'akismet_alert_usage_limit' ),
+			'upgrade_plan' => get_option( 'akismet_alert_upgrade_plan' ),
+			'upgrade_url'  => get_option( 'akismet_alert_upgrade_url' ),
+		);
+	}
+
+	public static function display_usage_limit_alert() {
+		Akismet::view( 'notice', self::get_usage_limit_alert_data() );
+	}
+
 	public static function display_spam_check_warning() {
 		Akismet::fix_scheduled_recheck();
 
@@ -1021,6 +1037,11 @@ class Akismet_Admin {
 			$notices[] = array( 'type' => $akismet_user->status );
 		}
 
+		$alert_code = get_option( 'akismet_alert_code' );
+		if ( isset( Akismet::$LIMIT_NOTICES[ $alert_code ] ) ) {
+			$notices[] = self::get_usage_limit_alert_data();
+		}
+
 		/*
 		// To see all variants when testing.
 		$notices[] = array( 'type' => 'active-notice', 'time_saved' => 'Cleaning up spam takes time. Akismet has saved you 1 minute!' );
@@ -1040,6 +1061,7 @@ class Akismet_Admin {
 		$notices[] = array( 'type' => 'new-key-failed' );
 		$notices[] = array( 'type' => 'limit-reached', 'level' => 'yellow' );
 		$notices[] = array( 'type' => 'limit-reached', 'level' => 'red' );
+		$notices[] = array( 'type' => 'usage-limit', 'api_calls' => '15000', 'usage_limit' => '10000', 'upgrade_plan' => 'Enterprise', 'upgrade_url' => 'https://akismet.com/account/' );
 		*/
 		
 		Akismet::log( compact( 'stat_totals', 'akismet_user' ) );
@@ -1056,9 +1078,14 @@ class Akismet_Admin {
 
 		if ( in_array( $hook_suffix, array( 'edit-comments.php' ) ) && (int) get_option( 'akismet_alert_code' ) > 0 ) {
 			Akismet::verify_key( Akismet::get_api_key() ); //verify that the key is still in alert state
-			
-			if ( get_option( 'akismet_alert_code' ) > 0 )
+		
+			$alert_code = get_option( 'akismet_alert_code' );
+			if ( isset( Akismet::$LIMIT_NOTICES[ $alert_code ] ) ) {
+				self::display_usage_limit_alert();
+			}
+			elseif ( $alert_code > 0 ) {
 				self::display_alert();
+			}
 		}
 		elseif ( ( 'plugins.php' === $hook_suffix || 'edit-comments.php' === $hook_suffix ) && ! Akismet::get_api_key() ) {
 			// Show the "Set Up Akismet" banner on the comments and plugin pages if no API key has been set.
